@@ -1,16 +1,14 @@
 import contextlib
 import dataclasses
-import datetime
 import urllib.parse
 from typing import Any, ContextManager, Type
 
-import psycopg2
-import psycopg2.extensions
+import psycopg
+import pymysql
 import sqlalchemy
 import sqlalchemy.ext.compiler
 import sqlalchemy.orm
 
-from iker.common.utils.funcutils import singleton
 from iker.common.utils.sequtils import head_or_none
 from iker.common.utils.strutils import is_blank
 
@@ -18,12 +16,6 @@ __all__ = [
     "DBAdapter",
     "orm_to_dict",
     "orm_clone",
-    "to_pg_date",
-    "to_pg_time",
-    "to_pg_ts",
-    "to_pg_ts",
-    "pg_date_max",
-    "pg_ts_max",
     "mysql_insert_ignore",
     "postgresql_insert_on_conflict_do_nothing",
 ]
@@ -35,8 +27,8 @@ class DBAdapter(object):
     """
 
     class Drivers:
-        Mysql = "mysql+mysqldb"
-        Postgresql = "postgresql+psycopg2"
+        Mysql = f"mysql+{pymysql.__name__}"
+        Postgresql = f"postgresql+{psycopg.__name__}"
 
     def __init__(
         self,
@@ -145,40 +137,6 @@ def orm_clone(orm: sqlalchemy.orm.DeclarativeBase, exclude: set[str] = None, no_
     return new_orm
 
 
-def to_pg_date(dt: datetime.datetime | datetime.date | int | float):
-    if isinstance(dt, (datetime.datetime, datetime.date)):
-        return psycopg2.extensions.DateFromPy(dt)
-    elif isinstance(dt, (int, float)):
-        return psycopg2.DateFromTicks(dt)
-    raise TypeError("should be one of 'datetime.datetime', 'datetime.date', 'int', 'float'")
-
-
-def to_pg_time(dt: datetime.time | int | float):
-    if isinstance(dt, datetime.time):
-        return psycopg2.extensions.TimeFromPy(dt)
-    elif isinstance(dt, (int, float)):
-        return psycopg2.TimeFromTicks(dt)
-    raise TypeError("should be one of 'datetime.time', 'int', 'float'")
-
-
-def to_pg_ts(dt: datetime.datetime | datetime.date | int | float):
-    if isinstance(dt, (datetime.datetime, datetime.date)):
-        return psycopg2.extensions.TimestampFromPy(dt)
-    elif isinstance(dt, (int, float)):
-        return psycopg2.TimestampFromTicks(dt)
-    raise TypeError("should be one of 'datetime.datetime', 'datetime.date', 'int', 'float'")
-
-
-@singleton
-def pg_date_max():
-    return psycopg2.Date(9999, 12, 31)
-
-
-@singleton
-def pg_ts_max():
-    return psycopg2.Timestamp(9999, 12, 31, 23, 59, 59.999, tzinfo=datetime.timezone.utc)
-
-
 def mysql_insert_ignore(enabled: bool = True):
     @sqlalchemy.ext.compiler.compiles(sqlalchemy.sql.Insert, "mysql")
     def dispatch(insert: sqlalchemy.sql.Insert, compiler: sqlalchemy.sql.compiler.SQLCompiler, **kwargs) -> str:
