@@ -142,8 +142,8 @@ def test_mysql_adapter(fixture_mysql_test_proc, fixture_mysql_test):
             dummy_float=rng.next_fixed(6),
             dummy_double=Decimal(rng.next_fixed(10)),
             dummy_date=rng.random_date(),
-            dummy_time=rng.random_time().replace(microsecond=0),
-            dummy_datetime=rng.random_datetime().replace(microsecond=0),
+            dummy_time=rng.random_time().replace(microsecond=0, tzinfo=None),
+            dummy_datetime=rng.random_datetime().replace(microsecond=0, tzinfo=None),
             dummy_json=rng.random_json_object(max_depth=5),
             dummy_unique_string=dummy_unique_string(),
         )
@@ -254,10 +254,10 @@ def test_postgresql_adapter(fixture_postgresql_test_proc, fixture_postgresql_tes
             dummy_float=rng.next_fixed(6),
             dummy_double_precision=rng.next_float(),
             dummy_date=rng.random_date(),
-            dummy_time=rng.random_time().replace(microsecond=0),
-            dummy_time_tz=rng.random_time().replace(microsecond=0, tzinfo=datetime.timezone.utc),
-            dummy_timestamp=rng.random_datetime().replace(microsecond=0),
-            dummy_timestamp_tz=rng.random_datetime().replace(microsecond=0, tzinfo=datetime.timezone.utc),
+            dummy_time=rng.random_time().replace(microsecond=0, tzinfo=None),
+            dummy_time_tz=rng.random_time().replace(microsecond=0),
+            dummy_timestamp=rng.random_datetime().replace(microsecond=0, tzinfo=None),
+            dummy_timestamp_tz=rng.random_datetime().replace(microsecond=0),
             dummy_array_varchar=list(rng.random_ascii(rng.next_int(0, 10)) for _ in range(rng.next_int(0, 10))),
             dummy_jsonb=rng.random_json_object(max_depth=5),
             dummy_json=rng.random_json_object(max_depth=5),
