@@ -1,9 +1,9 @@
-import datetime
 import unittest
 
 import ddt
 import pytest
 
+from iker.common.utils.dtutils import dt_utc_max, dt_utc_min
 from iker.common.utils.randutils import max_float, max_int, randomizer
 
 
@@ -109,7 +109,7 @@ class RandUtilsTest(unittest.TestCase):
             end = max(a, b)
             result = randomizer().random_datetime(begin, end)
 
-            self.assertTrue(datetime.datetime.min <= begin <= result <= end <= datetime.datetime.max)
+            self.assertTrue(dt_utc_min() <= begin <= result <= end <= dt_utc_max())
 
     def test_random_date(self):
         for _ in range(1000):
@@ -119,7 +119,7 @@ class RandUtilsTest(unittest.TestCase):
             end = max(a, b)
             result = randomizer().random_date(begin, end)
 
-            self.assertTrue(datetime.date.min <= begin <= result <= end <= datetime.date.max)
+            self.assertTrue(dt_utc_min().date() <= begin <= result <= end <= dt_utc_max().date())
 
     def test_random_time(self):
         for _ in range(1000):
@@ -129,4 +129,4 @@ class RandUtilsTest(unittest.TestCase):
             end = max(a, b)
             result = randomizer().random_time(begin, end)
 
-            self.assertTrue(datetime.time.min <= begin <= result <= end <= datetime.time.max)
+            self.assertTrue(dt_utc_min().timetz() <= begin <= result <= end <= dt_utc_max().timetz())
